@@ -393,6 +393,7 @@ class JSONNode:
         self._index = None
         self.parent = None
         self._id = uuid4().hex
+        self._child_objects = UUIDdict()
 
     def _set_new_uuid(self):
 
@@ -470,6 +471,7 @@ class JSONNode:
         return True
 
     def values(self, *keys, search_upwards=True, flat=False, **kwargs):
+        # TODO remake traversing childs case
         if flat is True and len(keys) > 1:
             raise ValueError(
                 "If flat argument is selected, you can only set one key value"
@@ -535,7 +537,7 @@ class JSONNode:
 
         # ---- DYNAMIC CONFIG ----
         if throw_exceptions_ is None:
-            throw_exceptions_ = config.query_exceptions
+            throw_exceptions_ = config.QUERY_EXCEPTIONS
         # ------------------------
         try:
             res = func(self)
@@ -677,7 +679,6 @@ class JSONCompose(JSONNode):
         By initializing instance, it assign types to child items
         """
         super().__init__(*args, **kwargs)
-        self._child_objects = UUIDdict()
         self._assign_children()
 
     @property
@@ -765,11 +766,11 @@ class JSONCompose(JSONNode):
 
         # ---- DYNAMIC CONFIG ----
         if recursive_ is None:
-            recursive_ = config.recursive_queries
+            recursive_ = config.RECURSIVE_QUERIES
         if include_parent_ is None:
-            include_parent_ = config.include_parents
+            include_parent_ = config.INCLUDE_PARENTS
         if native_types_ is None:
-            native_types_ = config.native_types
+            native_types_ = config.NATIVE_TYPES
         # ------------------------
         queryset = QuerySet()
         if native_types_:
@@ -807,13 +808,13 @@ class JSONCompose(JSONNode):
 
         # ---- DYNAMIC CONFIG ----
         if recursive_ is None:
-            recursive_ = config.recursive_queries
+            recursive_ = config.RECURSIVE_QUERIES
         if include_parent_ is None:
-            include_parent_ = config.include_parents
+            include_parent_ = config.INCLUDE_PARENTS
         if throw_exceptions_ is None:
-            throw_exceptions_ = config.query_exceptions
+            throw_exceptions_ = config.QUERY_EXCEPTIONS
         if native_types_ is None:
-            native_types_ = config.native_types
+            native_types_ = config.NATIVE_TYPES
         # ------------------------
         query = self.query(
             recursive_=recursive_,
@@ -929,11 +930,11 @@ class JSONCompose(JSONNode):
 
         # ---- DYNAMIC CONFIG ----
         if recursive_ is None:
-            recursive_ = config.recursive_queries
+            recursive_ = config.RECURSIVE_QUERIES
         if include_parent_ is None:
-            include_parent_ = config.include_parents
+            include_parent_ = config.INCLUDE_PARENTS
         if native_types_ is None:
-            native_types_ = config.native_types
+            native_types_ = config.NATIVE_TYPES
         # ------------------------
         queryset = KeyQuerySet()
         if native_types_:
@@ -972,13 +973,13 @@ class JSONCompose(JSONNode):
     ):
         # ---- DYNAMIC CONFIG ----
         if recursive_ is None:
-            recursive_ = config.recursive_queries
+            recursive_ = config.RECURSIVE_QUERIES
         if include_parent_ is None:
-            include_parent_ = config.include_parents
+            include_parent_ = config.INCLUDE_PARENTS
         if throw_exceptions_ is None:
-            throw_exceptions_ = config.query_exceptions
+            throw_exceptions_ = config.QUERY_EXCEPTIONS
         if native_types_ is None:
-            native_types_ = config.native_types
+            native_types_ = config.NATIVE_TYPES
         # ------------------------
         query = self.query_key(
             pattern,
@@ -1018,7 +1019,7 @@ class JSONCompose(JSONNode):
                 if item.is_composed and recursive:
                     item._remove_annotations()
 
-    @return_value_on_exception(empty, (IndexError, KeyError))
+    @return_value_on_exception(empty, (IndexError, KeyError, TypeError))
     def eval_path(
         self, path, fail_silently=False, native_types_=None, value_on_exception=None
     ):
@@ -1042,7 +1043,7 @@ class JSONCompose(JSONNode):
                 path = (path,)
 
         if native_types_ is None:
-            native_types_ = config.native_types
+            native_types_ = config.NATIVE_TYPES
 
         if not isinstance(path, (tuple, list)):
             raise TypeError(
@@ -1204,10 +1205,19 @@ class JSONSingleton(JSONNode):
     is_composed = False
 
     def query(self, **kwargs):
-        return QuerySet()
+        queryset = QuerySet()
+        queryset._native_types = kwargs.get("native_types_") or config.NATIVE_TYPES
+        return queryset
 
     def get(self, **kwargs):
-        return
+        if kwargs.get("native_types_") or config.NATIVE_TYPES:
+            return
+        return JSONNull(None)
+
+    def __getattr__(self, name):
+        if config.NATIVE_TYPES:
+            return
+        return JSONNull(None)
 
 
 # ---- COMPOSE OBJECTS ----
@@ -1226,7 +1236,7 @@ class JSONDict(dict, JSONCompose):
 
     def __dir__(self):
         # for autocompletion stuff
-        if config.autocomplete_only_nodes:
+        if config.AUTOCOMPLETE_ONLY_NODES:
             return list(self.keys())
         else:
             return list(self.keys()) + super().__dir__()
@@ -1261,7 +1271,9 @@ class JSONDict(dict, JSONCompose):
         try:
             return self.__getitem__(name)
         except KeyError:  # if a key error is thrown, then it will call __dir__
-            return
+            if config.NATIVE_TYPES:
+                return
+            return JSONNull(None)
 
     def __setitem__(self, k, v):
         """
@@ -1427,7 +1439,7 @@ class JSONList(list, JSONCompose):
         return self.__len__()
 
     def __dir__(self):
-        if config.autocomplete_only_nodes:
+        if config.AUTOCOMPLETE_ONLY_NODES:
             return [f"_{i}" for i in range(len(self))]
         else:
             return [f"_{i}" for i in range(len(self))] + super().__dir__()
